from __future__ import absolute_import

# import models into sdk package
from .models.applicant import Applicant
from .models.base import Base
from .models.carrier import Carrier
from .models.carrier_subsidiary import CarrierSubsidiary
from .models.county import County
from .models.county_bulk import CountyBulk
from .models.drug import Drug
from .models.drug_coverage import DrugCoverage
from .models.drug_coverage_response import DrugCoverageResponse
from .models.drug_package import DrugPackage
from .models.drug_search_response import DrugSearchResponse
from .models.meta import Meta
from .models.network import Network
from .models.network_search_response import NetworkSearchResponse
from .models.plan import Plan
from .models.plan_county import PlanCounty
from .models.plan_county_bulk import PlanCountyBulk
from .models.plan_search_response import PlanSearchResponse
from .models.plan_search_result import PlanSearchResult
from .models.pricing import Pricing
from .models.provider import Provider
from .models.provider_show_response import ProviderShowResponse
from .models.providers_search_response import ProvidersSearchResponse
from .models.rating_area import RatingArea
from .models.request_plan_find import RequestPlanFind
from .models.request_plan_find_applicant import RequestPlanFindApplicant
from .models.request_plan_find_provider import RequestPlanFindProvider
from .models.request_providers_search import RequestProvidersSearch
from .models.state import State
from .models.zip_code import ZipCode
from .models.zip_counties_response import ZipCountiesResponse
from .models.zip_county import ZipCounty
from .models.zip_county_bulk import ZipCountyBulk
from .models.zip_county_response import ZipCountyResponse

# import apis into sdk package
from .apis.drugs_api import DrugsApi
from .apis.networks_api import NetworksApi
from .apis.plans_api import PlansApi
from .apis.providers_api import ProvidersApi
from .apis.zip_counties_api import ZipCountiesApi

# import ApiClient
from .api_client import ApiClient

from .configuration import Configuration

configuration = Configuration()



from __future__ import absolute_import

# import models into model package
from .applicant import Applicant
from .base import Base
from .carrier import Carrier
from .carrier_subsidiary import CarrierSubsidiary
from .county import County
from .county_bulk import CountyBulk
from .drug import Drug
from .drug_coverage import DrugCoverage
from .drug_coverage_response import DrugCoverageResponse
from .drug_package import DrugPackage
from .drug_search_response import DrugSearchResponse
from .meta import Meta
from .network import Network
from .network_search_response import NetworkSearchResponse
from .plan import Plan
from .plan_county import PlanCounty
from .plan_county_bulk import PlanCountyBulk
from .plan_search_response import PlanSearchResponse
from .plan_search_result import PlanSearchResult
from .pricing import Pricing
from .provider import Provider
from .provider_show_response import ProviderShowResponse
from .providers_search_response import ProvidersSearchResponse
from .rating_area import RatingArea
from .request_plan_find import RequestPlanFind
from .request_plan_find_applicant import RequestPlanFindApplicant
from .request_plan_find_provider import RequestPlanFindProvider
from .request_providers_search import RequestProvidersSearch
from .state import State
from .zip_code import ZipCode
from .zip_counties_response import ZipCountiesResponse
from .zip_county import ZipCounty
from .zip_county_bulk import ZipCountyBulk
from .zip_county_response import ZipCountyResponse



# coding: utf-8

"""
ProvidersApi.py
Copyright 2016 SmartBear Software

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.
"""

from __future__ import absolute_import

import sys
import os

# python 2 and python 3 compatibility library
from six import iteritems

from ..configuration import Configuration
from ..api_client import ApiClient


class ProvidersApi(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        config = Configuration()
        if api_client:
            self.api_client = api_client
        else:
            if not config.api_client:
                config.api_client = ApiClient()
            self.api_client = config.api_client

    def get_provider(self, npi, **kwargs):
        """
        Find a Provider
        To retrieve a specific provider, just perform a GET using his NPI number

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_provider(npi, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str npi: NPI number (required)
        :param str vericred_api_key: API Key
        :return: ProviderShowResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['npi', 'vericred_api_key']
        all_params.append('callback')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_provider" % key
                )
            params[key] = val
        del params['kwargs']

        # verify the required parameter 'npi' is set
        if ('npi' not in params) or (params['npi'] is None):
            raise ValueError("Missing the required parameter `npi` when calling `get_provider`")

        resource_path = '/providers/{npi}'.replace('{format}', 'json')
        path_params = {}
        if 'npi' in params:
            path_params['npi'] = params['npi']

        query_params = {}

        header_params = {}
        if 'vericred_api_key' in params:
            header_params['Vericred-Api-Key'] = params['vericred_api_key']

        form_params = []
        local_var_files = {}

        body_params = None

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept([])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type([])

        # Authentication setting
        auth_settings = []

        response = self.api_client.call_api(resource_path, 'GET',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type='ProviderShowResponse',
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'))
        return response

    def get_providers(self, **kwargs):
        """
        Find Providers
        All `Provider` searches require a `zip_code`, which we use for weighting
the search results to favor `Provider`s that are near the user.  For example,
we would want "Dr. John Smith" who is 5 miles away to appear before
"Dr. John Smith" who is 100 miles away.

The weighting also allows for non-exact matches.  In our prior example, we
would want "Dr. Jon Smith" who is 2 miles away to appear before the exact
match "Dr. John Smith" who is 100 miles away because it is more likely that
the user just entered an incorrect name.

The free text search also supports Specialty name search and "body part"
Specialty name search.  So, searching "John Smith nose" would return
"Dr. John Smith", the ENT Specialist before "Dr. John Smith" the Internist.


        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_providers(callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param RequestProvidersSearch body: 
        :return: ProvidersSearchResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']
        all_params.append('callback')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_providers" % key
                )
            params[key] = val
        del params['kwargs']


        resource_path = '/providers/search'.replace('{format}', 'json')
        path_params = {}

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept([])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type([])

        # Authentication setting
        auth_settings = []

        response = self.api_client.call_api(resource_path, 'POST',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type='ProvidersSearchResponse',
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'))
        return response
